#ifndef SOFT_I2C_H
#define	SOFT_I2C_H
//------------------------------------------------------------------------------
#include "soft_i2c_Pins.h"
#include "soft_i2c_Prototypes.h"
//------------------------------------------------------------------------------
void softI2C_init()
{
  //Make SDA and SCK pins inputs initially
  SDA = 1;
  SCK = 1;
}
//------------------------------------------------------------------------------
void I2C_start()
{
  //Function Purpose: I2C_Start sends start bit sequence
  SCK = 1;
  SDA = 1;
  __delay_ms(1);
  SDA = 0;
}
//------------------------------------------------------------------------------
void I2C_restart()
{
  //Function Purpose: I2C_ReStart sends start bit sequence
  SCK = 0;
  __delay_ms(1);
  SDA = 1;
  __delay_ms(1);
  SCK = 1;
  __delay_ms(1);
  SDA = 0;
}
//------------------------------------------------------------------------------
void I2C_stop()
{
  //Function : I2C_Stop sends stop bit sequence
  SCK = 0;
  SDA = 0;
  __delay_ms(1);
  SCK = 1;
  __delay_ms(1);
  SDA = 1;
}
//------------------------------------------------------------------------------
void I2C_ack(char ackn)
{
  //Function : Send ACK/NACK bit sequence
  SCK = 0;
  SDA = ackn;     // 0 means ACK, 1 means NACK
  __delay_ms(1);
  SCK = 1;
}
//------------------------------------------------------------------------------
char I2C_write(char data)
{
  //Function Purpose: I2C_Write_Byte transfers one byte
  for(char Wr = 0 ; Wr < 8 ; Wr++ )
  {
    SCK = 0;
    SDA = ( ((data << Wr) & 0x80) ? 1 : 0 ); //MSB first
    SCK = 1;                                 //Toggle SCK pin So that slave can latch data bit
  }
  I2C_ack(ACK);                                //Ask for Acknowledgment from slave

  return SDATA;                              //Return ACK/NACK from slave
}
//------------------------------------------------------------------------------
char I2C_read(char status)
{
  //Function Purpose: I2C_Read_Byte reads one byte
  char data = 0;
  for( char Rd = 0 ; Rd < 8 ; Rd++ )
  {
    I2C_ack(NACK);                            //Not-Acknowledge
    data += ( SDATA << (7-Rd) );
  }
  I2C_ack(status);                             //Give final NACK to stop reading

  return data;
}
//------------------------------------------------------------------------------
#endif